.. geniac documentation master file, created by
   sphinx-quickstart on Sat Dec 14 00:00:42 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

geniac's documentation!
=======================


**Geniac**: **A**\u\ tomatic **C**\o\ nfiguration **GEN**\e\ rator and **I**\n\ staller for nextflow pipelines.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   overview
   process
   check
   install
   devcycle
   run
   cli
   admin
   faq
   misc

